=== modified file 'NEWS'
--- NEWS	2011-02-18 11:53:18 +0000
+++ NEWS	2011-02-18 16:58:04 +0000
@@ -18,6 +18,11 @@
  
   * Add lock dialog. (Daniel Schierbeck, #93652)
 
+ FEATURES
+
+  * Add option to use "bzr viz" with a vertical layout.
+    (Ximin Luo, #649273)
+
 0.99.1	2010-08-26
 
  BUG FIXES

=== modified file 'branchview/treeview.py'
--- branchview/treeview.py	2011-02-18 13:01:03 +0000
+++ branchview/treeview.py	2011-02-18 16:58:04 +0000
@@ -359,7 +359,7 @@
         cell.set_property("width-chars", 15)
         cell.set_property("ellipsize", pango.ELLIPSIZE_END)
         self.revno_column = gtk.TreeViewColumn("Revision No")
-        self.revno_column.set_resizable(False)
+        self.revno_column.set_resizable(True)
         self.revno_column.set_sizing(gtk.TREE_VIEW_COLUMN_FIXED)
         self.revno_column.set_fixed_width(cell.get_size(self.treeview)[2])
         self.revno_column.pack_start(cell, expand=True)
@@ -368,7 +368,7 @@
 
         self.graph_cell = CellRendererGraph()
         self.graph_column = gtk.TreeViewColumn()
-        self.graph_column.set_resizable(False)
+        self.graph_column.set_resizable(True)
         self.graph_column.set_sizing(gtk.TREE_VIEW_COLUMN_FIXED)
         self.graph_column.pack_start(self.graph_cell, expand=True)
         self.graph_column.add_attribute(self.graph_cell, "node", treemodel.NODE)
@@ -381,7 +381,7 @@
         cell.set_property("width-chars", 65)
         cell.set_property("ellipsize", pango.ELLIPSIZE_END)
         self.summary_column = gtk.TreeViewColumn("Summary")
-        self.summary_column.set_resizable(False)
+        self.summary_column.set_resizable(True)
         self.summary_column.set_expand(True)
         self.summary_column.set_sizing(gtk.TREE_VIEW_COLUMN_FIXED)
         self.summary_column.set_fixed_width(cell.get_size(self.treeview)[2])
@@ -393,7 +393,7 @@
         cell.set_property("width-chars", 15)
         cell.set_property("ellipsize", pango.ELLIPSIZE_END)
         self.committer_column = gtk.TreeViewColumn("Committer")
-        self.committer_column.set_resizable(False)
+        self.committer_column.set_resizable(True)
         self.committer_column.set_sizing(gtk.TREE_VIEW_COLUMN_FIXED)
         self.committer_column.set_fixed_width(200)
         self.committer_column.pack_start(cell, expand=True)
@@ -405,7 +405,7 @@
         cell.set_property("ellipsize", pango.ELLIPSIZE_END)
         self.date_column = gtk.TreeViewColumn("Date")
         self.date_column.set_visible(False)
-        self.date_column.set_resizable(False)
+        self.date_column.set_resizable(True)
         self.date_column.set_sizing(gtk.TREE_VIEW_COLUMN_FIXED)
         self.date_column.set_fixed_width(130)
         self.date_column.pack_start(cell, expand=True)

=== modified file 'viz/branchwin.py'
--- viz/branchwin.py	2011-02-18 13:01:03 +0000
+++ viz/branchwin.py	2011-02-18 16:58:04 +0000
@@ -98,7 +98,7 @@
         self.refresh_action.connect("activate", self._refresh_clicked)
         self.refresh_action.connect_accelerator()
 
-        self.construct()
+        self.vbox = self.construct()
 
     def _save_size_on_destroy(self, widget, config_name):
         """Creates a hook that saves the size of widget to config option 
@@ -117,18 +117,15 @@
         vbox = gtk.VBox(spacing=0)
         self.add(vbox)
 
-        self.paned = gtk.VPaned()
-        self.paned.pack1(self.construct_top(), resize=False, shrink=True)
-        self.paned.pack2(self.construct_bottom(), resize=True, shrink=False)
-        self.paned.show()
-
+        # order is important here
+        paned = self.construct_paned()
         nav = self.construct_navigation()
         menubar = self.construct_menubar()
+
         vbox.pack_start(menubar, expand=False, fill=True)
         vbox.pack_start(nav, expand=False, fill=True)
-
-        vbox.pack_start(self.paned, expand=True, fill=True)
-        vbox.set_focus_child(self.paned)
+        vbox.pack_start(paned, expand=True, fill=True)
+        vbox.set_focus_child(paned)
 
         self.treeview.connect('revision-selected',
                 self._treeselection_changed_cb)
@@ -138,6 +135,21 @@
         self.treeview.connect('tag-added', lambda w, t, r: self._update_tags())
         vbox.show()
 
+        return vbox
+
+    def construct_paned(self):
+        """Construct the main HPaned/VPaned contents."""
+        if self.config.get_user_option('viz-vertical') == 'True':
+            self.paned = gtk.HPaned()
+        else:
+            self.paned = gtk.VPaned()
+
+        self.paned.pack1(self.construct_top(), resize=False, shrink=True)
+        self.paned.pack2(self.construct_bottom(), resize=True, shrink=False)
+        self.paned.show()
+
+        return self.paned
+
     def construct_menubar(self):
         menubar = gtk.MenuBar()
 
@@ -189,6 +201,12 @@
         view_menu_compact.set_active(self.compact_view)
         view_menu_compact.connect('activate', self._brokenlines_toggled_cb)
 
+        view_menu_vertical = gtk.CheckMenuItem("Side-by-side Layout")
+        view_menu_vertical.set_active(False)
+        if self.config.get_user_option('viz-vertical') == 'True':
+            view_menu_vertical.set_active(True)
+        view_menu_vertical.connect('toggled', self._vertical_layout)
+
         view_menu_diffs = gtk.CheckMenuItem("Show Diffs")
         view_menu_diffs.set_active(False)
         if self.config.get_user_option('viz-show-diffs') == 'True':
@@ -209,6 +227,7 @@
 
         view_menu.add(view_menu_toolbar)
         view_menu.add(view_menu_compact)
+        view_menu.add(view_menu_vertical)
         view_menu.add(gtk.SeparatorMenuItem())
         view_menu.add(view_menu_diffs)
         view_menu.add(view_menu_wide_diffs)
@@ -531,6 +550,25 @@
             self.toolbar.hide()
         self.config.set_user_option('viz-toolbar-visible', col.get_active())
 
+    def _vertical_layout(self, col):
+        """Toggle the layout vertical/horizontal"""
+        self.config.set_user_option('viz-vertical', str(col.get_active()))
+
+        old = self.paned
+        self.vbox.remove(old)
+        self.vbox.pack_start(self.construct_paned(), expand=True, fill=True)
+        self._make_diff_paned_nonzero_size()
+        self._make_diff_nonzero_size()
+
+        self.treeview.emit('revision-selected')
+
+    def _make_diff_paned_nonzero_size(self):
+        """make sure the diff/revision pane isn't zero-width or zero-height"""
+        alloc = self.diff_paned.get_allocation()
+        if (alloc.width < 10) or (alloc.height < 10):
+            width, height = self.get_size()
+            self.diff_paned.set_size_request(width/3, int(height / 2.5))
+
     def _make_diff_nonzero_size(self):
         """make sure the diff isn't zero-width or zero-height"""
         alloc = self.diff.get_allocation()

